@@ -1,4 +1,26 @@
-(* $Id: gtkWindow.ml,v 1.38 2004/08/24 08:03:33 oandrieu Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: gtkWindow.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
 
 open Gaux
 open Gobject
@@ -96,6 +118,14 @@ module MessageDialog = struct
   external set_markup : [>`messagedialog] obj -> string -> unit = "ml_gtk_message_dialog_set_markup"
 end
 
+module AboutDialog = struct
+  include AboutDialog
+  external create : unit -> Gtk.about_dialog obj = "ml_gtk_about_dialog_new"
+
+  external set_email_hook : (string -> unit) -> unit = "ml_gtk_about_dialog_set_email_hook"
+  external set_url_hook   : (string -> unit) -> unit = "ml_gtk_about_dialog_set_url_hook"
+end
+
 module FileSelection = struct
   include FileSelection
   external create : string -> file_selection obj = "ml_gtk_file_selection_new"
